from flask import Flask,session
from flask_restful import Api,Resource
from flask_cors import *
import datetime


import sys,os
debug = False
if os.path.exists("./debug"):
    sys.path.insert(0,"./")
    debug = True

from IutyApi.stock.monitor_ import MonitorApi
from IutyApi.stock.resistance_ import ResistanceApi
from IutyApi.task.todo_ import TodoApi
from IutyApi.usr.login_ import LoginApi
from IutyApi.dev.api_ import ApiApi
from IutyApi.file.fileserver_ import FileServerApi

app = Flask(__name__,static_folder='static/',template_folder='static/template/')
api = Api(app)
CORS(app, supports_credentials=True)

host = '0.0.0.0'
port = 7780

app.config['SECRET_KEY'] = str(datetime.datetime.now())#'myskey'
app.config['SESSION_COOKIE_HTTPONLY'] = False
app.config['SESSION_PERMANENT'] = False
app.config['PERMANENT_SESSION_LIFETIME']=datetime.timedelta(days=30)

api.add_resource(MonitorApi,'/api/stock/monitor')
api.add_resource(ResistanceApi,'/api/stock/resistance')
api.add_resource(TodoApi,'/api/task/todo')
api.add_resource(LoginApi,'/api/usr/login')
api.add_resource(ApiApi,'/api/dev/api')

api.add_resource(FileServerApi,'/api/file/fileserver')

def main():
    app.run(host = host,port = port,debug = debug)

if __name__ == "__main__":
    main()
    pass



from IutyLib.database.mysql import MySql
from IutyLib.database.dbbase import *
from flask import session,request,send_from_directory
from flask_restful import Resource
import datetime,os


dbg = os.path.exists("./debug")
if dbg:
    mysql = MySql('139.9.137.187','root','fastcorp','dev',8510)
else:
    mysql = MySql('localhost','root','fastcorp','dev')

class Frm_Api_Data(mysql.Model):
    def queryRecord(self):
        data0 = self.query()
        data = {}
        for d0 in data0:
            if not d0["namespace"] in data:
                data[d0["namespace"]] = []
            data[d0["namespace"]].append(d0)
        return data
    
    def queryNamespaces(self):
        data = self.query(target=r"namespace")
        return data
    
    def queryApiInfo(self,aid):
        data = self.query(where=r"aid = '{}'".format(aid))
        return data
    
    def updateRecord(self,aid,name,namespace,url,description):
        if str(aid)[0] == "*":
            self.add(value=[{"name":name,"namespace":namespace,"url":url,"description":description}])
        else:
            self.update(value=[{"name":name,"namespace":namespace,"url":url,"description":description}],where=r"aid='{}'".format(aid))
        data = self.query(where=r"name='{}' and namespace = '{}'".format(name,namespace),orderby = "aid desc")
        return data
    
    def deleteRecord(self,aid):
        self.delete(where=r"aid='{}'".format(aid))
        pass
    pass

class Frm_Api_Param(mysql.Model):
    def queryRecord(self,aid):
        data0 = self.query(where=r"aid = '{}'".format(aid))
        data = {}
        for d0 in data0:
            if not d0["direction"] in data:
                data[d0["direction"]] = []
            data[d0["direction"]].append(d0)
        return data
    
    def updateRecord(self,aid,apid,key,direction,description):
        if str(apid) == "0":
            
            self.add(value=[{"aid":aid,"key":key,"direction":direction,"description":description}])
        else:
            self.update(value=[{"key":key,"direction":direction,"description":description}],where=r"apid='{}'".format(apid))
        
        pass
    
    def deleteRecord(self,apid):
        self.delete(where=r"apid='{}'".format(apid))
        pass
    
    def deleteApi(self,aid):
        self.delete(where=r"aid='{}'".format(aid))
        pass
    
    
class Frm_Api_Example_Data(mysql.Model):
    def queryRecord(self,aid):
        data = self.query(where = r"aid = '{}'".format(aid))
        return data
        
    def updateRecord(self,aid,name,eid,description):
        if str(eid) == "0":
            self.add(value=[{"aid":aid,"name":name,"description":description}])
        else:
            self.update(value=[{"name":name,"description":description}],where=r"eid='{}'".format(eid))
        pass
    
    def deleteRecord(self,eid):
        self.delete(where=r"eid='{}'".format(eid))
        pass
    
    def deleteApi(self,aid):
        self.delete(where=r"aid='{}'".format(aid))
        pass
    
class Frm_Api_Example_Param(mysql.Model):
    def queryRecord(self,eid):
        data = self.query(where = r"eid = '{}'".format(eid))
        return data
        
    def updateRecord(self,eid,apid,value,enabled):
        
        self.replace(value=[{"eid":eid,"apid":apid,"value":value,"enabled":enabled}])
        pass
    
    def deleteExample(self,eid):
        self.delete(where=r"eid='{}'".format(eid))
        pass
    
    def deleteApiParam(self,apid):
        self.delete(where=r"apid='{}'".format(apid))
        pass
    
    def deleteRecord(self,apid,eid):
        self.delete(where=r"apid='{}' and eid='{}'".format(apid,eid))
        pass

class V_Api_Example_Param(mysql.Model):
    def queryRecord(self,eid):
        data = self.query(where = r"eid = '{}' and direction = '0'".format(eid),orderby = "enabled desc")
        for d in data:
            
            if d['enabled'] == 1:
                d['enabled'] = True
            else:
                d['enabled'] = False
        return data

class V_Api_Example_Data(mysql.Model):
    def queryRecord(self,aid):
        data = self.query(where = r"aid = '{}'".format(aid))
        return data
    
class ApiApi(Resource):
    def getApis():
        rtn = {"success":False}
        
        db = Frm_Api_Data()
        data = db.queryRecord()
        
        
        rtn["success"] = True
        rtn["data"] = data
        return rtn
    
    def getApiInfo():
        rtn = {"success":False}
        aid = request.form.get('aid')
        if not aid:
            rtn["error"] = "aid is nesserary"
            return rtn
            
        db = Frm_Api_Data()
        data = db.queryApiInfo(aid)
        
        
        rtn["success"] = True
        rtn["data"] = data
        return rtn
    
    def deleteApiInfo():
        rtn = {"success":False}
        aid = request.form.get('aid')
        if not aid:
            rtn["error"] = "aid is nesserary"
            return rtn
            
        db = Frm_Api_Data()
        data = db.deleteRecord(aid)
        
        
        rtn["success"] = True
        rtn["data"] = data
        return rtn
    
    def getNamespaces():
        rtn = {"success":False}
        
        db = Frm_Api_Data()
        data = db.queryNamespaces()
        
        
        rtn["success"] = True
        rtn["data"] = data
        return rtn
    
    def updateApiInfo():
        rtn = {"success":False}
        aid = request.form.get("aid")
        name = request.form.get("name")
        namespace = request.form.get("namespace")
        url = request.form.get("url")
        description = request.form.get("description")
        debugurl = request.form.get("debugurl")
        
        if not aid:
            rtn["error"] = "aid is nesserary"
            return rtn
            
        if not name:
            rtn["error"] = "name is nesserary"
            return rtn
        
        if not namespace:
            rtn["error"] = "namespace is nesserary"
            return rtn
        
        if not url:
            rtn["error"] = "url is nesserary"
            return rtn
        
        if not description:
            rtn["error"] = "description is nesserary"
            return rtn
        
        db = Frm_Api_Data()
        db.updateRecord(aid,name,namespace,url,description)
        
        rtn['success'] = True
        
        return rtn
    
    def getApiParam():
        rtn = {"success":False}
        aid = request.form.get("aid")
        if not aid:
            rtn["error"] = "aid is nesserary"
            return rtn
            
        db = Frm_Api_Param()
        data = db.queryRecord(aid)
        
        
        rtn["success"] = True
        rtn["data"] = data
        return rtn
    
    
    def updateApiParam():
        rtn = {"success":False}
        aid = request.form.get("aid")
        apid = request.form.get("apid")
        
        key = request.form.get("key")
        
        direction = request.form.get("direction")
        description = request.form.get("description")
        
        
        if not aid:
            rtn["error"] = "aid is nesserary"
            return rtn
            
        if not key:
            rtn["error"] = "key is nesserary"
            return rtn
        
        if not apid:
            rtn["error"] = "apid is nesserary"
            return rtn
        
        if not direction:
            rtn["error"] = "direction is nesserary"
            return rtn
        
        if not description:
            rtn["error"] = "description is nesserary"
            return rtn
        
        db = Frm_Api_Param()
        db.updateRecord(aid,apid,key,direction,description)
        
        
        rtn['success'] = True
        
        return rtn
    
    def deleteApiParam():
        rtn = {"success":False}
        
        apid = request.form.get("apid")
        
        if not apid:
            rtn["error"] = "apid is nesserary"
            return rtn
        
        db = Frm_Api_Param()
        db.deleteRecord(apid)
        
        db = Frm_Api_Example_Param()
        db.deleteApiParam(apid)
        
        rtn['success'] = True
        
        return rtn
    
    def getExample():
        rtn = {"success":False}
        aid = request.form.get("aid")
        
        if not aid:
            rtn["error"] = "aid is nesserary"
            return rtn
        db = V_Api_Example_Data()
        data = db.queryRecord(aid)
        
        
        rtn["success"] = True
        rtn["data"] = data
        return rtn
    
    def updateExample():
        rtn = {"success":False}
        aid = request.form.get("aid")
        name = request.form.get("name")
        eid = request.form.get("eid")
        
        description = request.form.get("description")
        
        
        if not aid:
            rtn["error"] = "aid is nesserary"
            return rtn
            
        if not name:
            rtn["error"] = "name is nesserary"
            return rtn
        
        if not eid:
            rtn["error"] = "eid is nesserary"
            return rtn
        
        if not description:
            rtn["error"] = "description is nesserary"
            return rtn
        
        db = Frm_Api_Example_Data()
        db.updateRecord(aid,name,eid,description)
        
        rtn['success'] = True
        
        return rtn
    
    def deleteExample():
        rtn = {"success":False}
        eid = request.form.get("eid")
        
        if not eid:
            rtn["error"] = "eid is nesserary"
            return rtn
        db = Frm_Api_Example_Data()
        data = db.deleteRecord(eid)
        
        db = Frm_Api_Example_Param()
        data = db.deleteExample(eid)
        
        rtn["success"] = True
        
        return rtn
    
    def getExampleParam():
        rtn = {"success":False}
        eid = request.form.get("eid")
        if not eid:
            rtn["error"] = "eid is nesserary"
            return rtn
        
        db = V_Api_Example_Param()
        data = db.queryRecord(eid)
        
        
        rtn["success"] = True
        rtn["data"] = data
        return rtn
    
    def updateExampleParam():
        rtn = {"success":False}
        eid = request.form.get("eid")
        apid = request.form.get("apid")
        
        value = request.form.get("value")
        enabled = request.form.get("enabled")
        
        
        if not eid:
            rtn["error"] = "eid is nesserary"
            return rtn
        
        if not apid:
            rtn["error"] = "apid is nesserary"
            return rtn
        
        enabled = int(bool(enabled))
        
        
        db = Frm_Api_Example_Param()
        db.updateRecord(eid,apid,value,enabled)
        
        rtn['success'] = True
        
        return rtn
    

    
    def post(self):
        _cmd = request.form.get('cmd')
        if _cmd == 'getApis':
            return ApiApi.getApis()
        
        if _cmd == 'getApiInfo':
            return ApiApi.getApiInfo()
        
        if _cmd == 'getNamespaces':
            return ApiApi.getNamespaces()
        
        if _cmd == 'updateApiInfo':
            return ApiApi.updateApiInfo()
        
        if _cmd == 'deleteApiInfo':
            return ApiApi.deleteApiInfo()
        
        if _cmd == 'getApiParam':
            return ApiApi.getApiParam()
        
        if _cmd == 'updateApiParam':
            return ApiApi.updateApiParam()
        
        if _cmd == 'deleteApiParam':
            return ApiApi.deleteApiParam()
        
        if _cmd == 'updateExample':
            return ApiApi.updateExample()
        
        if _cmd == 'getExample':
            return ApiApi.getExample()
        
        if _cmd == 'deleteExample':
            return ApiApi.deleteExample()
        
        if _cmd == 'updateExampleParam':
            return ApiApi.updateExampleParam()
        
        if _cmd == 'getExampleParam':
            return ApiApi.getExampleParam()
        
        if _cmd == 'testExample':
            return ApiApi.testExample()
        
        if _cmd == 'getJqCode':
            return ApiApi.getJqCode()
    pass

if __name__ == "__main__":
    pass




from IutyLib.database.mysql import MySql
from IutyLib.database.dbbase import *
from flask import session,request,send_from_directory
from flask_restful import Resource
import datetime,os


dbg = os.path.exists("./debug")
debuglist = "3"
if dbg:
    mysql = MySql('139.9.137.187','root','fastcorp','task',8510)
else:
    mysql = MySql('localhost','root','fastcorp','task')

class Frm_Todo_Data(mysql.Model):
    def addRecord(self,title):
        self.add(value=[{"title":title,"finishdate":None,"filed":0}])
        pass
    
    def finishRecord(self,tid):
        data = self.query(where=r"tid = '{}'".format(tid))
        if len(data) > 0:
            if data[0]["finishdate"] is None:
                today = datetime.date.today()
                self.update(value=[{"finishdate":today}],where=r"tid = '{}'".format(tid))
            else:
                self.update(value=[{"finishdate":None}],where=r"tid = '{}'".format(tid))
        pass
    
    def fileRecord(self,tid):
        self.update(value=[{"filed":1}],where=r"tid = '{}'".format(tid))
        pass
    
    
    
    pass

class Frm_TodoList_Data(mysql.Model):
    def addRecord(self,lid,title):
        db0 = Frm_Todo_Data()
        db0.addRecord(title)
        data_l = db0.query(target=r"max(tid) as tid")
        
        self.add(value=[{"lid":lid,"tid":data_l[0]["tid"]}])
        pass
    
    def deleteRecord(self,lid):
        self.delete(where=r"lid='{}'".format(lid))
        pass
    
    def moveRecord(self,tid,tlid):
        self.update(value=[{"lid":tlid}],where=r"tid='{}'".format(tid))
    
    pass
        
    
class V_TodoList_Data(mysql.Model):
    def queryRecord(self,lid):
        data = self.query(where=r"lid = '{}' and filed = 0".format(lid),orderby = r"finishdate,tid")
        return data
    
    def fileRecord(self,lid):
        data = self.query(where=r"lid = '{}' and filed = 0 and not finishdate is Null".format(lid))
        
        db = Frm_Todo_Data()
        for d in data:
            db.fileRecord(d["tid"])
        pass

class Frm_TodoList_Info(mysql.Model):
    def addRecord(self,lid,name):
        self.add(value=[{"name":name}])
        lid = self.query(target=r"max(lid) as lid")[0]["lid"]
        return lid
    
    def renameTodoList(self,lid,name):
        self.update(value=[{"name":name}],where = r"lid = '{}'".format(lid))
        pass

class Frm_TodoList_Owner(mysql.Model):
    def addRecord(self,lid,uid,type):
        self.add(value=[{"uid":uid,"lid":lid,"type":type,"group1":"未分组","group2":"未分组"}])
    
    def updateGroup(self,lid,uid,group1,group2):
        self.update(value=[{"group1":group1,"group2":group2}],where=r"lid = '{}' and uid = '{}'".format(lid,uid))
    
    def deleteRecord(self,lid,uid):
        self.delete(where=r"uid='{}' and lid = '{}'".format(uid,lid))
    
    def queryGroupEnum(self,uid):
        data = {"group1":[],"group2":[]}
        group1 = self.query(target = r"group1",where=r"uid = '{}'".format(uid),groupby="group1")
        for g in group1:
            data["group1"].append(g["group1"])
        group2 = self.query(target = r"group2",where=r"uid = '{}'".format(uid),groupby="group2")
        for g in group2:
            data["group2"].append(g["group2"])
        return data
    pass

class V_TodoList_Info(mysql.Model):
    def queryRecord(self,uid):
        data = self.query(where=r"uid = '{}'".format(uid))
        return data
    
    def checkDefault(self,uid):
        data = self.queryRecord(uid)
        if len(data) == 0:
            self.addTodoList(uid,0,"待办集")
        pass
    
    def addTodoList(self,uid,type,name):
        lid = Frm_TodoList_Info().addRecord(uid,name)
        
        Frm_TodoList_Owner().addRecord(lid,uid,type)
        pass

class TodoApi(Resource):
    def query():
        rtn = {"success":False}
        lid = request.form.get("lid")
        if not lid:
            rtn["error"] = "lid is nesserary"
            return rtn
        
        data = V_TodoList_Data().queryRecord(lid)
        
        for d in data:
            if not d["finishdate"] == None:
                d["finishdate"] = datetime.datetime.strftime(d["finishdate"],"%Y-%m-%d")
        rtn["data"] = data
        rtn["success"] = True
        return rtn
        
    def finishTodo():
        rtn = {"success":False}
        tid = request.form.get("tid")
        lid = request.form.get("lid")
        if not tid:
            rtn["error"] = "tid is nesserary"
            return rtn
        if not lid:
            rtn["error"] = "lid is nesserary"
            return rtn
        
        Frm_Todo_Data().finishRecord(tid)
        
        rtn["success"] = True
        return rtn
    
    def addTodo():
        rtn = {"success":False}
        title = request.form.get("title")
        lid = request.form.get("lid")
        if not title:
            rtn["error"] = "title is nesserary"
            return rtn
        if not lid:
            rtn["error"] = "lid is nesserary"
            return rtn
        
        Frm_TodoList_Data().addRecord(lid,title)
        
        rtn["success"] = True
        return rtn
    
    def fileTodo():
        rtn = {"success":False}
        lid = request.form.get("lid")
        if not lid:
            rtn["error"] = "lid is nesserary"
            return rtn
        
        V_TodoList_Data().fileRecord(lid)
        rtn["success"] = True
        return rtn
    
    def moveTodo():
        rtn = {"success":False}
        tid = request.form.get("tid")
        
        tlid = request.form.get("tlid")
        if not tid:
            rtn["error"] = "tid is nesserary"
            return rtn
        
        
        if not tlid:
            rtn["error"] = "tlid is nesserary"
            return rtn
        
        Frm_TodoList_Data().moveRecord(tid,tlid)
        rtn["success"] = True
        return rtn
    
    def queryTodoList():
        rtn = {"success":False}
        uid = session.get("uid")
        if not uid:
            uid = 1
        db = V_TodoList_Info()
        db.checkDefault(uid)
        data = db.queryRecord(uid)
        for d in data:
            d["done"] = int(d["done"])
            d["total"] = int(d["total"])
        rtn["success"] = True
        rtn["data"] = data
        return rtn
    
    def queryGroupEnum():
        rtn = {"success":False}
        uid = session.get("uid")
        if not uid:
            uid = 1
        
        db = Frm_TodoList_Owner()
        data = db.queryGroupEnum(uid)
        
        rtn["data"] = data
        rtn["success"] = True
        return rtn
    
    def addTodoList():
        rtn = {"success":False}
        uid = session.get("uid")
        if not uid:
            uid = 1
        
        db = V_TodoList_Info()
        db.checkDefault(uid)
        db.addTodoList(uid,1,"新增待办集")
        
        
        rtn["success"] = True
        return rtn
    
    def renameTodoList():
        rtn = {"success":False}
        lid = request.form.get("lid")
        if not lid:
            rtn["error"] = "lid is nesserary"
            return rtn
        
        name = request.form.get("name")
        if not name:
            rtn["error"] = "name is nesserary"
            return rtn
        
        db = Frm_TodoList_Info()
        db.renameTodoList(lid,name)
        
        
        
        rtn["success"] = True
        return rtn
        
    def updateGroup():
        rtn = {"success":False}
        lid = request.form.get("lid")
        if not lid:
            rtn["error"] = "lid is nesserary"
            return rtn
        
        uid = session.get("uid")
        if not uid:
            uid = 1
        
        group1 = request.form.get("group1")
        if not group1:
            group1 = "未分组"
        
        group2 = request.form.get("group2")
        if not group2:
            group2 = "未分组"
        
        db = Frm_TodoList_Owner()
        db.updateGroup(lid,uid,group1,group2)
        
        
        
        rtn["success"] = True
        return rtn
    
    def removeTodoList():
        rtn = {"success":False}
        lid = request.form.get("lid")
        if not lid:
            rtn["error"] = "lid is nesserary"
            return rtn
        
        uid = session.get("uid")
        if not uid:
            uid = 1
        
        db = Frm_TodoList_Owner()
        db.deleteRecord(lid,uid)
        
        rtn["success"] = True
        return rtn
    
    def post(self):
        _cmd = request.form.get('cmd')
        if _cmd == 'queryTodo':
            return TodoApi.query()
        
        if _cmd == 'finishTodo':
            return TodoApi.finishTodo()
        
        if _cmd == 'addTodo':
            return TodoApi.addTodo()
        
        if _cmd == 'fileTodo':
            return TodoApi.fileTodo()
        
        if _cmd == 'moveTodo':
            return TodoApi.moveTodo()
        
        if _cmd == 'removeTodo':
            return TodoApi.removeTodo()
        
        if _cmd == "addTodoList":
            return TodoApi.addTodoList()
        
        if _cmd == "queryTodoList":
            return TodoApi.queryTodoList()
        
        if _cmd == "queryGroupEnum":
            return TodoApi.queryGroupEnum()
        
        if _cmd == "renameTodoList":
            return TodoApi.renameTodoList()
        
        if _cmd == "updateGroup":
            return TodoApi.updateGroup()
        
        if _cmd == "removeTodoList":
            return TodoApi.removeTodoList()
    pass

if __name__ == "__main__":
    
    #Frm_Task_Todo().fileRecord(1)
    #Frm_TodoList_Data().addRecord("2","ttl1")
    d = V_TodoList_Data().queryRecord(3)
    print(d)




from IutyLib.database.mysql import MySql
from IutyLib.database.dbbase import *
from flask import session,request,send_from_directory
from flask_restful import Resource
import datetime,os


dbg = os.path.exists("./debug")
if dbg:
    mysql = MySql('139.9.137.187','root','fastcorp','usr',8510)
else:
    mysql = MySql('localhost','root','fastcorp','usr')

class Srv_Login_Password(mysql.Model):
    def addRecord(self,usr,psw):
        self.replace(value=[{"usr":usr,"psw":psw}])
        pass
    
    def queryRecord(self,usr):
        data = self.query(where=r"usr='{}'".format(usr))
        return data
    
    def updateRecord(self,usr,psw):
        self.update(value=[{"psw":psw}],where=r"usr='{}'".format(usr))
        pass
    pass
    
class LoginApi(Resource):
    def addUsr():
        rtn = {"success":False}
        usr = request.form.get("usr")
        if not usr:
            rtn["error"] = "usr is nesserary"
            return rtn
        
        Srv_Login_Password().addRecord(usr,"777777")
        
        rtn["success"] = True
        return rtn
    
    def login():
        rtn = {"success":False}
        usr = request.form.get("usr")
        psw = request.form.get("psw")
        
        if not usr:
            rtn["error"] = "usr is nesserary"
            return rtn
            
        if not psw:
            rtn["error"] = "psw is nesserary"
            return rtn
        
        data = Srv_Login_Password().queryRecord(usr)
        
        if len(data) > 0:
            if data[0]["psw"] == psw:
                #login ok
                session["usr"] = usr
                session["uid"] = data[0]["uid"]
                rtn["success"] = True
                return rtn
            else:
                #login failed
                rtn["error"] = "user and password is not matched"
                return rtn
        else:
            rtn["error"] = "user is not exists"
            return rtn
    
    def reset():
        rtn = {"success":False}
        usr = request.form.get("usr")
        if not usr:
            usr = session.get("usr")
        if not usr:
            rtn["error"] = "usr in nesserary"
            return rtn
        
        Srv_Login_Password().updateRecord(usr,"777777")
        rtn["success"] = True
        return rtn
    
    def modifyPassword():
        rtn = {"success":False}
        usr = session.get("usr")
        psw = request.form.get("psw")
        if not usr:
            rtn["error"] = "modify api must in login mode"
            return rtn
        
        if not psw:
            rtn["error"] = "psw is nesserary"
            return rtn
        Srv_Login_Password().updateRecord(usr,psw)
        rtn["success"] = True
        return rtn
    
    def quit():
        rtn = {"success":False}
        session.clear()
        
        rtn["success"] = True
        return rtn
    
    def status():
        rtn = {"success":False}
        uid = session.get("uid")
        data = {"login":False}
        if uid:
            data["login"] = True
        rtn["data"] = data
        rtn["success"] = True
        return rtn
    
    def post(self):
        _cmd = request.form.get('cmd')
        if _cmd == 'addUsr':
            return LoginApi.addUsr()
            
        if _cmd == 'login':
            return LoginApi.login()
        
        if _cmd == 'reset':
            return LoginApi.reset()
        
        if _cmd == 'modifyPsw':
            return LoginApi.modifyPassword()
        
        if _cmd == 'quit':
            return LoginApi.quit()
        
        if _cmd == 'status':
            return LoginApi.status()
    pass

if __name__ == "__main__":
    print(Srv_Login_Password().queryRecord("t.yu"))




from flask import session,request,send_from_directory,Response
from flask_restful import Resource
import datetime,os,time,base64,json

fileserverpath = r"/dbdisk/fileserver"

def createDir():
    t = time.time()
    t = str(int(t*100))
    dirname = base64.encodebytes(t.encode('utf8'))
    dirname = str(dirname,encoding="utf-8").strip()
    
    dirpath = os.path.join(fileserverpath,dirname)
    os.mkdir(dirpath)
    
    return dirname

def getIndexTag(index,tag = None):
    obj_index = loadIndex(index)
    if not obj_index:
        raise Exception("index {} is not exists".format(index))
        
    if tag:
        if tag in obj_index:
            return obj_index[tag]
    
    obj_tag = None
    
    for idx in obj_index:
        if not obj_tag:
            obj_tag = obj_index[idx]
            continue
        if obj_tag["update"] < obj_index[idx]["update"]:
            obj_tag = obj_index[idx]
    
    if obj_tag["update"] == 0:
        raise Exception("json have no records")
    return obj_tag

def getIndexList(index,tag=None):
    
    dirname = getIndexTag(index,tag)["path"]
    
    ls = []
    rootpath = os.path.join(fileserverpath,dirname)
    for mdir,sdirs,fs in os.walk(rootpath):
        if len(fs) > 0:
            for f in fs:
                ls.append(os.path.join(mdir,f).replace(rootpath,"")[1:])
    
    data = {"dirname":dirname,"filelist":ls}
    
    return data

def setUpdate(item_index):
    item_index["update"] = int(time.time())
    pass

def loadIndex(index):
    path_index = os.path.join(fileserverpath,"index","{}.json".format(index))
    if not os.path.exists(path_index):
        return None
    f = open(path_index,"r",encoding='utf-8')
    obj_index = json.load(f)
    f.close()
    return obj_index

def saveIndex(index,obj_index):
    path_index = os.path.join(fileserverpath,"index","{}.json".format(index))
    f = open(path_index,"w+",encoding='utf-8')
    json.dump(obj_index,f,indent=4)
    f.close()
    pass

def push(index,tag = None):
    dirname = createDir()
    obj_index = loadIndex(index)
    if not obj_index:
        obj_index = {}
    
    if not tag:
        tag = dirname
    obj_index[tag] = {"path":dirname}
    setUpdate(obj_index[tag])
    
    saveIndex(index,obj_index)
    return dirname

def setTag(index,tag,tagname):
    obj_index = loadIndex(index)
    
    if tag in obj_index:
        edittag = obj_index.pop(tag)
        obj_index[tagname] = edittag
        setUpdate(obj_index[tagname])
        saveIndex(index,obj_index)
    else:
        raise Exception("tag {} is not exists".format(tag))
    pass

def listIndex():
    data = os.listdir(os.path.join(fileserverpath,"index"))
    
    data = [d[:-5] for d in data if d[-5:] == ".json"]
    return data

def listTag(index):
    obj_index = loadIndex(index)
    if not obj_index:
        raise Exception("index is not exists")
    return list(obj_index.keys())


def append(dirname,filename,stream,start,mode):
    fullpath = os.path.join(fileserverpath,dirname,filename)
    reldirname = os.path.dirname(fullpath)
    if not os.path.exists(reldirname):
        os.makedirs(reldirname)
    if start:
        if os.path.exists(fullpath):
            if "-r" == mode:
                os.remove(fullpath)
            else:
                return
    #f = open(fullpath,"wb")
    #f.write(stream)
    #f.close()
    stream.save(fullpath)
    pass
    
def fetch(dirname,filename):
    """
    abort and instead of get method
    """
    fullpath = os.path.join(fileserverpath,dirname,filename)
    print(fullpath)
    if not os.path.exists(fullpath):
        raise Exception("{}/{} is not exists".format(dirname,filename))
    
    f = open(fullpath,"rb")
    stream = f.read()
    
    #stream = base64
    #data = {"dirname":dirname,"filename":filename,"stream":stream}
    response = Response(stream, content_type='application/octet-stream')
    response.headers["Content-disposition"] = 'attachment; filename=%s' % filename
    return response
    

class FileServerApi(Resource):
    """
    File Server reply a file resource service
    No Usr confirm
    No Git
    """
    
    def push():
        """
        push directory to remote
        create a new directory
        """
        index = request.form.get("index")
        tag = request.form.get("tag")
        if not index:
            raise Exception("index is nesserary")
        dirname = push(index,tag)
        return dirname
    
    def pull():
        """
        pull directory from remote
        """
        index = request.form.get("index")
        tag = request.form.get("tag")
        
        if not index:
            raise Exception("index is nesserary")
        
        
        return getIndexList(index,tag)
        
    
    def append():
        """
        append a file to [tag/last]
        """
        dirname = request.form.get("dirname")
        if not dirname:
            raise Exception("dirname is nesserary")
        
        filename = request.form.get("filename")
        if not filename:
            raise Exception("filename is nesserary")
        
        stream = request.files.get("file")
        print(stream)
        if not stream:
            raise Exception("stream is nesserary")
        
        start = request.form.get("start")
        mode = request.form.get("mode")
        if mode != "-r":
            mode = "-s"
        
        append(dirname,filename,stream,start,mode)
        
        pass
    
    def fetch():
        """
        fetch a file from [tag/last]
        """
        dirname = request.args.get("dirname")
        if not dirname:
            raise Exception("dirname is nesserary")
        
        filename = request.args.get("filename")
        if not filename:
            raise Exception("filename is nesserary")
        
        return fetch(dirname,filename)
        pass
    
    def tag():
        """
        set tag to resource
        """
        index = request.form.get("index")
        tag = request.form.get("tag")
        tagname = request.form.get("tagname")
        
        if not index:
            raise Exception("index is nesserary")
        
        if not tag:
            raise Exception("tag is nesserary")
        
        if not tagname:
            raise Exception("tagname is nesserary")
            
        setTag(index,tag,tagname)
        pass
    
    def lists():
        """
        list resource
        """
        index = request.form.get("index")
        
        if not index:
            return listIndex()
        else:
            return listTag(index)
        pass
    
    def response_post():
        cmd = request.form.get('cmd')
        if not cmd:
            raise Exception("cmd is nesserary")
            
        if "push" == cmd:
            return FileServerApi.push()
        
        if "pull" == cmd:
            return FileServerApi.pull()
        
        if "append" == cmd:
            return FileServerApi.append()
        
        if "tag" == cmd:
            return FileServerApi.tag()
        
        if "list" == cmd:
            return FileServerApi.lists()
    
    def response_get():
        
        cmd = request.args.get('cmd')
        
        if "fetch" == cmd:
            res = FileServerApi.fetch()
            return res
            
    
    def post(self):
        rtn = {"success":False}
        
        try:
            data = FileServerApi.response_post()
            rtn["success"] = True
            if data:
                rtn["data"] = data
            else:
                rtn["error"] = "unrecorgnised cmd"
                
        except Exception as err:
            rtn["error"] = str(err)
            #raise err
        return rtn
    
    def get(self):
        res = FileServerApi.response_get()
        
        return res

if __name__ == "__main__":
    print(getNewDirName())


from setuptools import setup

version = '1.21.0418.0051'

entry_points={
        'console_scripts': [
            'ipb = IutyApi.server.webserver:main'
        ]
    }

setup(
    name="IutyApi",
    version= version,
    #version = ver,
    packages=[
        "IutyApi.stock",
        "IutyApi.task",
        "IutyApi.usr",
        "IutyApi.dev",
        "IutyApi.file",
        
        "IutyApi.server",
        
        ]
)